MLECO-2160: Error repor when Ethos-U is not used

Change-Id: I0dab5308bf5c3eba9b4bb2c9bf0939ac9598d2f6
diff --git a/source/application/tensorflow-lite-micro/include/Model.hpp b/source/application/tensorflow-lite-micro/include/Model.hpp
index 70e17ad..b814da4 100644
--- a/source/application/tensorflow-lite-micro/include/Model.hpp
+++ b/source/application/tensorflow-lite-micro/include/Model.hpp
@@ -84,8 +84,11 @@
         /** @brief  Checks if the model uses signed data. */
         bool IsDataSigned() const;
 
-         /** @brief  Runs the inference (invokes the interpreter). */
-         virtual bool RunInference();
+        /** @brief Checks if the model uses Ethos-U operator */
+        bool ContainsEthosUOperator() const;
+
+        /** @brief  Runs the inference (invokes the interpreter). */
+        virtual bool RunInference();
 
         /** @brief   Model information handler common to all models.
          *  @return  true or false based on execution success.